// ###################################################################################################
// Versionning du plugin
//
// 1.0.0 Version initiale du plugin
// 1.0.1 
// ###################################################################################################
/*
 SalomeTMF is a Test Management Framework
 * Copyright (C) 2007 EDF / France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * @author Jrmie DEFAYE
 *
 * Contact: mikael.marche@rd.francetelecom.com
 */


package salomeTMF_plug.ExtractAttachments;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Map;
import java.util.Vector;
import javax.swing.JMenu;
import javax.swing.JMenuItem;

import org.java.plugin.ExtensionPoint;
import org.java.plugin.Plugin;
import org.java.plugin.PluginDescriptor;
import org.java.plugin.PluginManager;
import org.objectweb.salome_tmf.api.Api;
import org.objectweb.salome_tmf.data.DataConstants;
import org.objectweb.salome_tmf.data.Project;
import org.objectweb.salome_tmf.ihm.IHMConstants;
import org.objectweb.salome_tmf.ihm.tools.Tools;
import org.objectweb.salome_tmf.plugins.IPlugObject;
import org.objectweb.salome_tmf.plugins.core.Admin;
import org.objectweb.salome_tmf.plugins.core.Common;

import salomeTMF_plug.ExtractAttachments.language.Language;
import salomeTMF_plug.ExtractAttachments.sqlWrapper.SQLWrapper;

/**
 * Plugin that can import or export data between SalomeTMF and Excel
 * 
 * @version 1
 */
public class ExtractAttachments extends Plugin implements Common, Admin,
		DataConstants, IHMConstants {

	// SalomeTMF pIhm;
    /**
     * Plugin gel
     */
	private boolean isFreezed = false;

    /**
     * JMenu onglet Test
     */
	private JMenu testGendocSubMenu = null;

    /**
     * JMenu onglet Campagne
     */
	private JMenu campGendocSubMenu = null;

    /**
     * JMenu onglet Donnes
     */
	private JMenu dataGendocSubMenu = null;

    /**
     * JMenu onglet Test
     */
	private JMenu testEchangeDonneesSubMenu = null;

    /**
     * JMenu onglet Campagne
     */
	private JMenu campEchangeDonneesSubMenu = null;

    /**
     * JMenu onglet Donnes
     */
	private JMenu dataEchangeDonneesSubMenu = null;

    /**
     * Variable Interface Homme Machine
     */
	private IPlugObject pIPlugObject;

	/**
	 * Plugin that can import or export data between SalomeTMF and Excel
	 * 
	 * @param manager
	 *            Manager
	 * @param descr
	 *            Description
	 */
	public ExtractAttachments(PluginManager manager, PluginDescriptor descr) {
		super(manager, descr);
	}

	/**
	 * see org.java.plugin.Plugin()
	 * 
	 * @throws java.lang.Exception
	 *             Erreur language
	 */
	protected void doStart() throws Exception {
		// no-op
	}

	/**
	 * see org.java.plugin.Plugin()
	 * 
	 * @throws java.lang.Exception
	 *             Erreur Language
	 */
	protected void doStop() throws Exception {
		// no-op
	}

	/**
	 * salome.plugins.core.Common
	 * 
	 * @param pIPlugObject
	 *            Interface Homme Machine
	 */
	public void init(Object pIPlugObject) {
		 try {
			SQLWrapper.init(Api.getISQLObjectFactory());
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		this.pIPlugObject = (IPlugObject) pIPlugObject;
	}

	/**
	 * salome.plugins.core.Common
	 * 
	 * @return True
	 */
	public boolean isActivableInTestToolsMenu() {
		return true;
	}

	/**
	 * salome.plugins.core.Common
	 * 
	 * @return True
	 */
	public boolean isActivableInCampToolsMenu() {
		return true;
	}

	/**
	 * salome.plugins.core.Common
	 * 
	 * @return True
	 */
	public boolean isActivableInDataToolsMenu() {
		return true;
	}

	/**
	 * see salome.plugins.core.Common
	 * 
	 * @return False
	 */
	public boolean usesOtherUIComponents() {
		return false;
	}

	/**
	 * see salome.plugins.core.Common
	 * 
	 * @param testToolsMenu
	 *            Menu
	 */
	public void activatePluginInTestToolsMenu(JMenu testToolsMenu) {
		testToolsMenu.addSeparator();
		testToolsMenu.add(createJMenu());

	}

	/**
	 * see salome.plugins.core.Common
	 * 
	 * @param campToolsMenu
	 *            Menu
	 */
	public void activatePluginInCampToolsMenu(JMenu campToolsMenu) {
		campToolsMenu.addSeparator();
		campToolsMenu.add(createJMenu());

	}

	/**
	 * see salome.plugins.core.Common
	 * 
	 * @param dataToolsMenu
	 *            dataToolsMenu
	 */
	public void activatePluginInDataToolsMenu(JMenu dataToolsMenu) {
		dataToolsMenu.addSeparator();
		dataToolsMenu.add(createJMenu());
	}

	/**
	 * Cre le menu de Salom
	 * 
	 * @return Menu cr
	 */
	public JMenu createJMenu() {

		JMenu attachmentsSubMenu;
		attachmentsSubMenu = new JMenu(Language.getInstance().getText("Plugin_Attachments"));
		JMenuItem detachItem = new JMenuItem(Language.getInstance().getText("Detacher_les_pieces_jointes_du_projet"));
	

		

		detachItem.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				try {
					new DetachAttachment(pIPlugObject);
				} catch (Exception ex) {
					Tools.ihmExceptionView(ex);
				}
			}
		});

		attachmentsSubMenu.add(detachItem);
		return attachmentsSubMenu;
	}

	/**
	 * see salome.plugins.core.Common
	 * 
	 * @return Null
	 */
	public Vector getUsedUIComponents() {
		return null;
	}

	/**
	 * see salome.plugins.core.Common
	 * 
	 * @param uiCompCst
	 *            Nombre
	 */
	public void activatePluginInStaticComponent(Integer uiCompCst) {
	}

	/**
	 * see salome.plugins.core.Common
	 * 
	 * @param uiCompCst
	 *            Nombre
	 */
	public void activatePluginInDynamicComponent(Integer uiCompCst) {
	}

	/**
	 * see salome.plugins.core.Common
	 * 
	 * @return True
	 */
	public boolean isFreezable() {
		return true;
	}

	/**
	 * see salome.plugins.core.Common
	 */
	public void freeze() {
		testGendocSubMenu.setEnabled(false);
		campGendocSubMenu.setEnabled(false);
		dataGendocSubMenu.setEnabled(false);
		isFreezed = true;
	}

	/**
	 * see salome.plugins.core.Common
	 */
	public void unFreeze() {
		testGendocSubMenu.setEnabled(true);
		campGendocSubMenu.setEnabled(true);
		dataGendocSubMenu.setEnabled(true);
		isFreezed = false;
	}

	/**
	 * see salome.plugins.core.Common
	 * 
	 * @return isFreezed
	 */
	public boolean isFreezed() {
		return isFreezed;
	}

	/**
	 * see
	 * org.objectweb.salome_tmf.plugins.core.Admin#activateInSalomeAdmin(java.util.Map)
	 * 
	 * @param commonExtensions
	 *            ExtensionPoint
	 * @param testDriverExtensions
	 *            ExtensionPoint
	 * @param scriptEngineExtensions
	 *            ExtensionPoint
	 * @param bugTrackerExtensions
	 *            ExtensionPoint
	 * @param businessIntelligenceExtensions
	 *            ExtensionPoint
	 */
	public void allPluginActived(
			ExtensionPoint commonExtensions, 
			ExtensionPoint testDriverExtensions, 
			ExtensionPoint scriptEngineExtensions, 
			ExtensionPoint bugTrackerExtensions,
			ExtensionPoint businessIntelligenceExtensions) {
	}
	/**
	 * see
	 * org.objectweb.salome_tmf.plugins.core.Admin#activateInSalomeAdmin(java.util.Map)
	 * 
	 * @param commonExtensions
	 *            ExtensionPoint
	 * @param testDriverExtensions
	 *            ExtensionPoint
	 * @param scriptEngineExtensions
	 *            ExtensionPoint
	 * @param bugTrackerExtensions
	 *            ExtensionPoint
	 */
	public void allPluginActived(
			ExtensionPoint commonExtensions, 
			ExtensionPoint testDriverExtensions, 
			ExtensionPoint scriptEngineExtensions, 
			ExtensionPoint bugTrackerExtensions) {
	}
	// ////////////////////////////// Admin interface
	// ////////////////////////////////////

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.objectweb.salome_tmf.plugins.core.Admin#activateInSalomeAdmin(java.util.Map)
	 */
	/**
	 * Non Javadoc
	 * 
	 * @param adminUIComps
	 *            Map
	 * @param iPlugObject
	 *            IPlugObject
	 */
	public void activateInSalomeAdmin(final Map adminUIComps,
			IPlugObject iPlugObject) {
		// !\\ Pour la frame parent de la fenetre secondaire ->
		// Administarion.ptrFrame
	}

	/**
	 * Non Javadoc
	 * 
	 * @param p
	 *            Project
	 */
	public void onDeleteProject(Project p) {

	}

}
