/*
* SalomeTMF is a Test Management Framework
* Copyright (C) 2005 France Telecom R&D
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* @author Marche Mikael
*
* Contact: mikael.marche@rd.francetelecom.com
*/

package salomeTMF_plug.ExtractAttachments.sqlWrapper;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.Properties;

import org.objectweb.salome_tmf.api.Util;
import org.objectweb.salome_tmf.api.sql.IDataBase;
import org.objectweb.salome_tmf.api.sql.ISQLEngine;
import org.objectweb.salome_tmf.api.sql.ISQLObjectFactory;

/**
 * @author Jrmie DEFAYE
 *
 */
public class SQLWrapper {
	static Properties comonQuery;
	
	static IDataBase db; 

	static ISQLEngine pISQLEngine = null;
	
	/**
	 * @param pISQLObjectFactory
	 * @throws Exception
	 */
	public static void init (ISQLObjectFactory pISQLObjectFactory) throws Exception{
		comonQuery =   Util.getPropertiesFile(SQLWrapper.class.getResource("/salomeTMF_plug/ExtractAttachments/resources/sql/commonSqlQuery.properties"));
		db = pISQLObjectFactory.getInstanceOfSalomeDataBase();
		Util.log("[SQLWrapper->init] database is " + db);
		pISQLEngine = pISQLObjectFactory.getCurrentSQLEngine();
		String SqlLockWrite = comonQuery.getProperty("myLockWrite");
		Util.log("[SQLWrapper->init] Add lock Write " + SqlLockWrite + " to " + pISQLEngine);
		String SqlLockRead = comonQuery.getProperty("myLockRead");
		Util.log("[SQLWrapper->init] Add lock Read " + SqlLockRead + " to " + pISQLEngine);
		//pISQLEngine.addSQLLoackWrite(SqlLockWrite);
		//pISQLEngine.addSQLLoackRead(SqlLockRead);
		
	}
	
	
	
	/**
	 * @param queryName
	 * @return PreparedStatement
	 * @throws Exception
	 */
	public static PreparedStatement getSQLAddQuery (String queryName)  throws Exception{
		Util.log("[SQLWrapper->getSQLAddQuery]" + queryName);
		String sql = comonQuery.getProperty(queryName);
		Util.log("[SQLWrapper->getSQLAddQuery] sql is " + sql);
		PreparedStatement prep = db.prepareStatement(sql);
		return prep;
	}
	
	/**
	 * @param queryName
	 * @return PreparedStatement
	 * @throws Exception
	 */
	public static PreparedStatement getSQLCommonQuery (String queryName)  throws Exception{
		Util.log("[SQLWrapper->getSQLCommonQuery]" + queryName);
		String sql = comonQuery.getProperty(queryName);
		Util.log("[SQLWrapper->getSQLCommonQuery] sql is " + sql);
		PreparedStatement prep = db.prepareStatement(sql);
		return prep;
	}
	
	/**
	 * @param queryName
	 * @return PreparedStatement
	 * @throws Exception
	 */
	public static PreparedStatement getSQLSelectQuery (String queryName)  throws Exception{
		Util.log("[SQLWrapper->getSQLSelectQuery]" + queryName + " : " + comonQuery);
		String sql = comonQuery.getProperty(queryName);
		Util.log("[SQLWrapper->getSQLSelectQuery] sql is " + sql);
		PreparedStatement prep = db.prepareStatement(sql);
		return prep;
	}
	
	/**
	 * @param queryName
	 * @return PreparedStatement
	 * @throws Exception
	 */
	public static PreparedStatement getSQLUpdateQuery (String queryName)  throws Exception{
		Util.log("[SQLWrapper->getSQLUpdateQuery]" + queryName);
		String sql = comonQuery.getProperty(queryName);
		Util.log("[SQLWrapper->getSQLUpdateQuery] sql is " + sql);
		PreparedStatement prep = db.prepareStatement(sql);
		return prep;
	}
	
	/**
	 * @param queryName
	 * @return PreparedStatement
	 * @throws Exception
	 */
	public static PreparedStatement getSQLDeleteQuery (String queryName)  throws Exception{
		Util.log("[SQLWrapper->getSQLDeleteQuery]" + queryName);
		String sql = comonQuery.getProperty(queryName);
		Util.log("[SQLWrapper->getSQLDeleteQuery] sql is " + sql);
		PreparedStatement prep = db.prepareStatement(sql);
		return prep;
	}
	
		
	/**
	 * @param prep
	 * @return PreparedStatement
	 * @throws Exception
	 */
	public static synchronized  int runAddQuery(PreparedStatement prep) throws Exception{
		return prep.executeUpdate();
	}
	/**
	 * @param prep
	 * @return PreparedStatement
	 * @throws Exception
	 */
	public static synchronized  int runDeleteQuery(PreparedStatement prep) throws Exception{
		return prep.executeUpdate();
	}
	/**
	 * @param prep
	 * @return PreparedStatement
	 * @throws Exception
	 */
	public static synchronized  int runUpdateQuery(PreparedStatement prep ) throws Exception{
		return prep.executeUpdate();
	}
	/**
	 * @param prep
	 * @return PreparedStatement
	 * @throws Exception
	 */
	public static synchronized  ResultSet runSelectQuery(PreparedStatement prep) throws Exception{
		return prep.executeQuery();
	}
	
	/**
	 * @return PreparedStatement
	 * @throws Exception
	 */
	static public synchronized  int beginTransaction() throws Exception {
		return pISQLEngine.beginTransDB(0, 1000);
	}
	
	/**
	 * @param id
	 * @throws Exception
	 */
	static synchronized public void commitTrans(int id) throws Exception {
		pISQLEngine.commitTransDB(id);
	}
	
	/**
	 * @param id
	 * @throws Exception
	 */
	static synchronized  public void rollBackTrans(int id) throws Exception{
		pISQLEngine.rollForceBackTransDB(id);
	}
	
	

}
